package com.nisum.ecomcustomer.model;

import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.data.annotation.Id;
import org.springframework.data.annotation.Transient;
import org.springframework.data.annotation.TypeAlias;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.data.mongodb.core.mapping.Field;

import javax.validation.Valid;
import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import java.util.List;

@NoArgsConstructor
@Data
@TypeAlias("customer")
@Document("customers")
public class Customer {

    @Transient
    public static final String SEQUENCE_NAME = "customers_sequence";

    @Id
    private Long id;
    @Field("fName")
    @NotBlank(message = "first name can't be blank")
    private String firstName;
    @Field("lName")
    private String lastName;
    @Indexed(unique = true)
    @NotBlank(message = "email is mandatory")
    @Email
    private String email;
    @NotBlank(message = "dayPhone can't be blank")
    private String dayPhone;
    @Field("type")
    private CustomerType customerType;
    @Valid
    private List<Address> addresses;

    // TODO - add audit fields

//    @CreatedDate
//    private LocalDateTime createdDate;
//
//    @LastModifiedDate
//    private LocalDateTime modifiedDate;
}
