package com.nisum.ecomcustomer.service.impl;

import com.nisum.ecomcustomer.exceptions.CustomerNotFoundException;
import com.nisum.ecomcustomer.model.Customer;
import com.nisum.ecomcustomer.repository.CustomerRepository;
import com.nisum.ecomcustomer.service.CustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class CustomerServiceImpl implements CustomerService {

    @Autowired
    CustomerRepository customerRepository;

    @Override
    public Customer register(Customer customer) {
        return customerRepository.save(customer);
    }

    @Override
    public List<Customer> registerAll(List<Customer> customers) {
        return customerRepository.saveAll(customers);
    }

    @Override
    public List<Customer> getAllCustomers() {
        return customerRepository.findAll();
    }

    @Override
    public Customer getCustomerById(Long id) {
        return customerRepository.findById(id).orElseThrow(CustomerNotFoundException::new);
    }

    @Override
    public Customer getCustomerByEmail(String email) {
        return customerRepository.findByEmailIgnoreCase(email);
    }

    @Override
    public List<Customer> getCustomerByFirstName(String fName) {
        return customerRepository.findByFirstName(fName);
    }

    @Override
    public List<Customer> getCustomerByLastName(String lName) {
        return customerRepository.findByLastNameIgnoreCase(lName);
    }

    @Override
    public void deleteById(Long id) {
        if (customerRepository.existsById(id)) customerRepository.deleteById(id);
        else throw new CustomerNotFoundException(id);
    }

}
